@@ -44,13 +44,13 @@ static grn_ctx *ctx = NULL;
 PG_MODULE_MAGIC;
 
 extern PGDLLEXPORT void _PG_init(void);
-extern PGDLLEXPORT void pgroonga_crash_safer_reset_position_one(Datum datum)
+extern PGDLLEXPORT pg_noreturn void
+pgroonga_crash_safer_reset_position_one(Datum datum) pg_attribute_noreturn();
+extern PGDLLEXPORT pg_noreturn void
+pgroonga_crash_safer_reindex_one(Datum datum) pg_attribute_noreturn();
+extern PGDLLEXPORT pg_noreturn void pgroonga_crash_safer_flush_one(Datum datum)
 	pg_attribute_noreturn();
-extern PGDLLEXPORT void pgroonga_crash_safer_reindex_one(Datum datum)
-	pg_attribute_noreturn();
-extern PGDLLEXPORT void pgroonga_crash_safer_flush_one(Datum datum)
-	pg_attribute_noreturn();
-extern PGDLLEXPORT void pgroonga_crash_safer_main(Datum datum)
+extern PGDLLEXPORT pg_noreturn void pgroonga_crash_safer_main(Datum datum)
 	pg_attribute_noreturn();
 
 static volatile sig_atomic_t PGroongaCrashSaferGotSIGTERM = false;
@@ -297,8 +297,9 @@ pgroonga_crash_safer_reindex_one(Datum databaseInfoDatum)
 			}
 			else
 			{
-				indexNames[i] = pnstrdup(VARDATA_ANY(indexName),
-										 VARSIZE_ANY_EXHDR(indexName));
+				indexNames[i] =
+					pnstrdup(VARDATA_ANY(DatumGetPointer(indexName)),
+							 VARSIZE_ANY_EXHDR(DatumGetPointer(indexName)));
 			}
 		}
 
